@@ -50,7 +50,6 @@ struct format_table_conv_make_item {
   static_assert(Base <= 36, "Base is unrepresentable");
   struct make_item {
     std::size_t index{};
-    constexpr explicit make_item(std::size_t index_) : index(index_) {} // gcc49
     constexpr char alpha(std::size_t ord) const {
       return static_cast<char>(
           ord < 10 ? '0' + ord : (Upper ? 'A' : 'a') + (ord - 10));
@@ -149,7 +148,7 @@ void FormatValue<double>::formatHelper(
   switch (arg.presentation) {
     case '%':
       val *= 100;
-      FOLLY_FALLTHROUGH;
+      [[fallthrough]];
     case 'f':
     case 'F': {
       if (arg.precision > DoubleToStringConverter::kMaxFixedDigitsAfterPoint) {
@@ -427,8 +426,4 @@ void insertThousandsGroupingUnsafe(char* start_buffer, char** end_buffer) {
 FormatKeyNotFoundException::FormatKeyNotFoundException(StringPiece key)
     : std::out_of_range(kMessagePrefix.str() + key.str()) {}
 
-#if FOLLY_CPLUSPLUS < 201703L
-constexpr StringPiece const FormatKeyNotFoundException::kMessagePrefix;
-#endif
-
 } // namespace folly
