@@ -30,8 +30,10 @@
 
 #include <glog/logging.h>
 #include <folly/ScopeGuard.h>
+#include <folly/concurrency/ProcessLocalUniqueId.h>
 #include <folly/synchronization/LifoSem.h>
 #include <folly/synchronization/ThrottledLifoSem.h>
+#include <folly/tracing/StaticTracepoint.h>
 
 namespace folly {
 
@@ -85,6 +87,7 @@ class EDFThreadPoolExecutor::Task {
   std::shared_ptr<RequestContext> context_ = RequestContext::saveContext();
   std::chrono::steady_clock::time_point enqueueTime_ =
       std::chrono::steady_clock::now();
+  uint64_t taskId_ = processLocalUniqueId();
 };
 
 class EDFThreadPoolExecutor::TaskQueue {
@@ -93,7 +96,7 @@ class EDFThreadPoolExecutor::TaskQueue {
 
   // This is not a `Synchronized` because we perform a few "peek" operations.
   struct Bucket {
-    SharedMutex mutex;
+    mutable SharedMutex mutex;
 
     struct Compare {
       bool operator()(const TaskPtr& lhs, const TaskPtr& rhs) const {
@@ -289,7 +292,9 @@ void EDFThreadPoolExecutor::add(Func f, std::size_t total, uint64_t deadline) {
     return;
   }
 
-  taskQueue_->push(std::make_shared<Task>(std::move(f), total, deadline));
+  auto task = std::make_shared<Task>(std::move(f), total, deadline);
+  registerTaskEnqueue(*task);
+  taskQueue_->push(std::move(task));
 
   auto numIdleThreads = numIdleThreads_.load(std::memory_order_seq_cst);
   if (numIdleThreads > 0) {
@@ -305,7 +310,9 @@ void EDFThreadPoolExecutor::add(std::vector<Func> fs, uint64_t deadline) {
   }
 
   auto total = fs.size();
-  taskQueue_->push(std::make_shared<Task>(std::move(fs), deadline));
+  auto task = std::make_shared<Task>(std::move(fs), deadline);
+  registerTaskEnqueue(*task);
+  taskQueue_->push(std::move(task));
 
   auto numIdleThreads = numIdleThreads_.load(std::memory_order_seq_cst);
   if (numIdleThreads > 0) {
@@ -315,6 +322,10 @@ void EDFThreadPoolExecutor::add(std::vector<Func> fs, uint64_t deadline) {
   }
 }
 
+size_t EDFThreadPoolExecutor::getTaskQueueSize() const {
+  return taskQueue_->size();
+}
+
 void EDFThreadPoolExecutor::threadRun(ThreadPtr thread) {
   this->threadPoolHook_.registerThread();
   ExecutorBlockingGuard guard{
@@ -344,30 +355,40 @@ void EDFThreadPoolExecutor::threadRun(ThreadPtr thread) {
 
     thread->idle.store(false, std::memory_order_relaxed);
     auto startTime = std::chrono::steady_clock::now();
-    TaskStats stats;
-    stats.enqueueTime = task->enqueueTime_;
-    if (task->context_) {
-      stats.requestId = task->context_->getRootId();
-    }
+    ProcessedTaskInfo taskInfo;
+    fillTaskInfo(*task, taskInfo);
+    taskInfo.waitTime = startTime - taskInfo.enqueueTime;
+    FOLLY_SDT(
+        folly,
+        thread_pool_executor_task_dequeued,
+        threadFactory_->getNamePrefix().c_str(),
+        taskInfo.requestId,
+        taskInfo.enqueueTime.time_since_epoch().count(),
+        taskInfo.waitTime.count(),
+        taskInfo.taskId);
+    forEachTaskObserver(
+        [&](auto& observer) { observer.taskDequeued(taskInfo); });
 
-    stats.waitTime = startTime - stats.enqueueTime;
     invokeCatchingExns("EDFThreadPoolExecutor: func", [&] {
       std::exchange(task, {})->run(iter);
     });
-    stats.runTime = std::chrono::steady_clock::now() - startTime;
+    taskInfo.runTime = std::chrono::steady_clock::now() - startTime;
+
+    FOLLY_SDT(
+        folly,
+        thread_pool_executor_task_taskInfo,
+        threadFactory_->getNamePrefix().c_str(),
+        taskInfo.requestId,
+        taskInfo.enqueueTime.time_since_epoch().count(),
+        taskInfo.waitTime.count(),
+        taskInfo.runTime.count(),
+        taskInfo.taskId);
+    forEachTaskObserver(
+        [&](auto& observer) { observer.taskProcessed(taskInfo); });
+
     thread->idle.store(true, std::memory_order_relaxed);
     thread->lastActiveTime.store(
         std::chrono::steady_clock::now(), std::memory_order_relaxed);
-    auto& inCallback = *thread->taskStatsCallbacks->inCallback;
-    thread->taskStatsCallbacks->callbackList.withRLock([&](auto& callbacks) {
-      inCallback = true;
-      SCOPE_EXIT { inCallback = false; };
-      invokeCatchingExns("EDFThreadPoolExecutor: stats callback", [&] {
-        for (auto& callback : callbacks) {
-          callback(stats);
-        }
-      });
-    });
   }
 }
 
@@ -379,7 +400,7 @@ void EDFThreadPoolExecutor::stopThreads(std::size_t numThreads) {
 
 // threadListLock_ is read (or write) locked.
 std::size_t EDFThreadPoolExecutor::getPendingTaskCountImpl() const {
-  return taskQueue_->size();
+  return getTaskQueueSize();
 }
 
 bool EDFThreadPoolExecutor::shouldStop() {
@@ -413,7 +434,9 @@ std::shared_ptr<EDFThreadPoolExecutor::Task> EDFThreadPoolExecutor::take() {
   // No tasks on the horizon, so go sleep
   numIdleThreads_.fetch_add(1, std::memory_order_seq_cst);
 
-  SCOPE_EXIT { numIdleThreads_.fetch_sub(1, std::memory_order_seq_cst); };
+  SCOPE_EXIT {
+    numIdleThreads_.fetch_sub(1, std::memory_order_seq_cst);
+  };
 
   for (;;) {
     if (FOLLY_UNLIKELY(shouldStop())) {
@@ -434,4 +457,26 @@ std::shared_ptr<EDFThreadPoolExecutor::Task> EDFThreadPoolExecutor::take() {
   }
 }
 
+void EDFThreadPoolExecutor::fillTaskInfo(const Task& task, TaskInfo& info) {
+  info.priority = 0; // Priorities are not supported.
+  if (task.context_) {
+    info.requestId = task.context_->getRootId();
+  }
+  info.enqueueTime = task.enqueueTime_;
+  info.taskId = task.taskId_;
+}
+
+void EDFThreadPoolExecutor::registerTaskEnqueue(const Task& task) {
+  TaskInfo info;
+  fillTaskInfo(task, info);
+  forEachTaskObserver([&](auto& observer) { observer.taskEnqueued(info); });
+  FOLLY_SDT(
+      folly,
+      thread_pool_executor_task_enqueued,
+      threadFactory_->getNamePrefix().c_str(),
+      info.requestId,
+      info.enqueueTime.time_since_epoch().count(),
+      info.taskId);
+}
+
 } // namespace folly
